
## Application Config

::: mountaineer.config.ConfigBase

::: mountaineer.config.get_config

## Internal Functions

Used in unit testing or some other scenarios where you need specific control over the configuration that is mounted into the global registry.

::: mountaineer.config.register_config

::: mountaineer.config.unregister_config

::: mountaineer.config.get_config
